========
gMeterPy
========

.. image:: https://img.shields.io/travis/opengrav/gmeterpy.svg
        :target: https://travis-ci.org/opengrav/gmeterpy
        :alt: TravisCI build status

.. image:: https://codecov.io/gh/opengrav/gmeterpy/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/opengrav/gmeterpy
        :alt: Test coverage status

.. image:: https://readthedocs.org/projects/gmeterpy/badge/?version=latest
        :target: https://gmeterpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/gitter/room/opengrav/gmeterpy.svg 
        :target: https://gitter.im/opengrav/gmeterpy
        :alt: Chat room on Gitter


Gravity (small `g`) measurement data processing framework written in Python.

The goal of the gMeterPy is to create an open source software to process 
raw data from all types of gravimeters.

**The project is in the early planning and development stage.**

About
-----

*gMeterPy* is an open source and free Python library for processing 
measurement data from gravimeters, which are used for gravity field surveys 
in geodesy, geophysics and other branches of Earth and planetary sciences. 
The main intention is to go as deep as possible in processing **raw** data 
from scratch, as well as to support all types of instruments, 
corrections, common file formats and processing procedures.

Install
-------

You will need **Python 3.5 or greater**.

To install ``gMeterPy`` simply use ``pip`` as usual: 

.. code:: bash

    pip install https://github.com/opengrav/gmeterpy/archive/master.zip

Or clone the git repository locally and run:

.. code:: bash

    git clone https://github.com/opengrav/gmeterpy.git
    cd gmeterpy
    pip install .


Contributing
------------

There are many ways you can contribute! Please read 
`CONTRIBUTING.rst <https://github.com/opengrav/gmeterpy/blob/master/CONTRIBUTING.rst>`__
to see how you can help and give feedback.

Please note also that *gMeterPy* is released with a Code of Conduct 
(see `CODE_OF_CONDUCT.md <https://github.com/opengrav/gmeterpy/blob/master/CODE_OF_CONDUCT.md>`__).
By participating in this project you agree that you will follow all its terms.

License
-------

This project is licensed under the MIT license. 
Please see `LICENSE.txt <https://github.com/opengrav/gmeterpy/blob/master/LICENSE.txt>`__ 
for details.

